@@ -10,7 +10,23 @@
 #' @param alpha Concentration parameter for the prior placed on documents' distributions over topics. This is a singleton which is replicated to a vector of length \code{k} in fitting (as currently EM optimizer only supports symmetric distributions, so all values in the vector should be the same). For Expectation-Maximization optimizer values should be > 1.0.
 #' By default \code{alpha = (50 / k) + 1}, where \code{50/k} is common in LDA libraries and +1 follows from Asuncion et al. (2009), who recommend a +1 adjustment for EM.
 #' @param beta Concentration parameter for the prior placed on topics' distributions over terms. For Expectation-Maximization optimizer value should be > 1.0 and by default \code{beta = 0.1 + 1}, where 0.1 gives a small amount of smoothing and +1 follows Asuncion et al. (2009), who recommend a +1 adjustment for EM.
+#' @examples
+#' \dontrun{
+#' library(janeaustenr)
+#' library(sparklyr)
+#' library(dplyr)
 #'
+#' sc <- spark_connect(master = "local")
+#'
+#' austen_books <- austen_books()
+#' books_tbl <- sdf_copy_to(sc, austen_books, overwrite = TRUE)
+#' first_tbl <- books_tbl %>% filter(nchar(text) > 0) %>% head(100)
+#'
+#' first_tbl %>%
+#'   ft_tokenizer("text", "tokens") %>%
+#'   ft_count_vectorizer("tokens", "features") %>%
+#'   ml_lda("features", k = 4)
+#' }
 #' @references
 #' Original LDA paper (journal version): Blei, Ng, and Jordan. "Latent Dirichlet Allocation." JMLR, 2003.
 #'
@@ -26,8 +42,9 @@
 #' For terminology used in LDA model see \href{https://spark.apache.org/docs/latest/api/scala/index.html#org.apache.spark.ml.clustering.LDA}{Spark LDA documentation}.
 #'
 #' @export
+#' @importFrom dplyr tbl_vars
 ml_lda <- function(x,
-                   features = dplyr::tbl_vars(x),
+                   features = tbl_vars(x),
                    k = length(features),
                    alpha = (50 / k) + 1,
                    beta = 0.1 + 1,
