@@ -7,6 +7,7 @@
 #' @template roxlate-ml-features
 #' @template roxlate-ml-intercept
 #' @template roxlate-ml-regression-penalty
+#' @template roxlate-ml-weights-column
 #' @template roxlate-ml-iter-max
 #' @template roxlate-ml-options
 #' @template roxlate-ml-dots
@@ -20,6 +21,7 @@ ml_linear_regression <- function(x,
                                  intercept = TRUE,
                                  alpha = 0,
                                  lambda = 0,
+                                 weights.column = NULL,
                                  iter.max = 100L,
                                  ml.options = ml_options(),
                                  ...)
@@ -42,6 +44,7 @@ ml_linear_regression <- function(x,
 
   alpha <- ensure_scalar_double(alpha)
   lambda <- ensure_scalar_double(lambda)
+  weights.column <- ensure_scalar_character(weights.column, allow.null = TRUE)
   iter.max <- ensure_scalar_integer(iter.max)
   only.model <- ensure_scalar_boolean(ml.options$only.model)
 
@@ -65,6 +68,11 @@ ml_linear_regression <- function(x,
     invoke("setElasticNetParam", as.double(alpha)) %>%
     invoke("setRegParam", as.double(lambda))
 
+  if (!is.null(weights.column)) {
+    model <- model %>%
+      invoke("setWeightCol", weights.column)
+  }
+
   if (is.function(ml.options$model.transform))
     model <- ml.options$model.transform(model)
 
@@ -110,6 +118,7 @@ ml_linear_regression <- function(x,
            features = features,
            response = response,
            intercept = intercept,
+           weights.column = weights.column,
            coefficients = coefficients,
            standard.errors = errors,
            t.values = tvalues,
@@ -147,3 +156,29 @@ summary.ml_model_linear_regression <- function(object, ...) {
   cat(paste("R-Squared:", signif(object$r.squared, 4)), sep = "\n")
   cat(paste("Root Mean Squared Error:", signif(object$root.mean.squared.error, 4)), sep = "\n")
 }
+
+#' @export
+residuals.ml_model_linear_regression <- function(object, ...) {
+
+  residuals <- object$.model %>%
+    invoke("summary") %>%
+    invoke("residuals")
+
+  sdf_read_column(residuals, "residuals")
+
+}
+
+#' @export
+#' @rdname sdf_residuals
+sdf_residuals.ml_model_linear_regression <- function(
+  object, ...) {
+
+  residuals <- object$.model %>%
+    invoke("summary") %>%
+    invoke("residuals") %>%
+    sdf_register()
+
+  ml_model_data(object) %>%
+    select(- !!! rlang::sym(object$model.parameters$id)) %>%
+    sdf_fast_bind_cols(residuals)
+}
