@@ -60,11 +60,10 @@ na.omit.spark_jobj <- function(object, columns = NULL, ...) {
 
   # using a df created from drop actions reduces performance, see #308.
   if (identical(n_before, n_after)) {
-    object
+    sdf_register(object)
   } else {
     result <- sdf_register(dropped)
     invoke(spark_dataframe(result), "cache")
-
     result
   }
 }
